pub struct ReactionEquation { /* private fields */ }Expand description
A chemical reaction equation with reactants, products, and an arrow.
Implementations
Sourceimpl ReactionEquation
impl ReactionEquation
Sourcepub fn with_reactant<T>(self, reactant: T) -> Self
pub fn with_reactant<T>(self, reactant: T) -> Self
Adds a reactant and returns the updated equation.
Sourcepub fn with_product<T>(self, product: T) -> Self
pub fn with_product<T>(self, product: T) -> Self
Adds a product and returns the updated equation.
Sourcepub const fn with_arrow(self, arrow: ReactionArrow) -> Self
pub const fn with_arrow(self, arrow: ReactionArrow) -> Self
Sets the reaction arrow.
Sourcepub const fn arrow(&self) -> ReactionArrow
pub const fn arrow(&self) -> ReactionArrow
Returns the reaction arrow.
Sourcepub fn validate(&self) -> Result<(), ReactionValidationError>
pub fn validate(&self) -> Result<(), ReactionValidationError>
Validates that the equation has at least one reactant and one product.
Errors
Returns ReactionValidationError::EmptyReaction when no reaction-side terms are present,
ReactionValidationError::MissingReactants when no reactants are present, or
ReactionValidationError::MissingProducts when no products are present.